# UpdateEntry

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**args** | [**dict(str, AdvanceArg)**](AdvanceArg.md) |  | [optional] 
**data** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**investigation_id** | **str** |  | [optional] 
**markdown** | **bool** |  | [optional] 
**version** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


